# Notif - The notification package for every python project
[![License: GPL v3](https://img.shields.io/badge/License-GPL%20v3-blue.svg)](http://www.gnu.org/licenses/gpl-3.0)
[![Build Status](https://travis-ci.com/davebulaval/notification.svg?branch=master)](https://travis-ci.com/davebulaval/notification)

Notif is a easy to use package to send notification from a python script.

Use this package to send during or at the end of a python script a

    - Slack notification
    - email notification.
    
Read the documentation at [Notificationdoc.ca](https://notificationdoc.ca).

---------

## Installation

```shell script
pip install notif
```

